/***************************************************************************
                          dirview.cpp  -  description
                             -------------------
    begin                : Sat Nov 20 1999
    copyright            : (C) 1999 by Rene Mrten, Christian Fricke
                           und Torsten Enkelmann
    email                : @-Mail to: delta_x@LinuxCoding.DE
                                      cfricke@LinuxCoding.DE
                                      Torsten@LinuxCoding.DE
****************************************************************************/

#include "dirview.h"
#include "Iconfiles/minus.xpm"
#include "Iconfiles/plus.xpm"
#include "Iconfiles/firstcorner.xpm"
#include "Iconfiles/senk.xpm"
#include "Iconfiles/waage.xpm"
#include "Iconfiles/leer.xpm"
#include <qfont.h>
#include <qdir.h>


dirview::dirview(listView *LV, const char *dirPath, QWidget *parent, const char *name) : QWidget(parent,name){
	
	horSlider = new QScrollBar ( 0, 0, 1, 1, 0, QScrollBar::Horizontal, this);
	verSlider = new QScrollBar ( 0, 0, 1, 1, 0, QScrollBar::Vertical, this);
	
	lv = LV;
	
	Liste = 0;
  	this->setFont(QFont("helvetica", 12, 50));
   pmBuffer = new QPixmap(100,100);

	dirviewItem *dv = addItem(dirPath,dirPath);
	dv->expandable = 2;	// PLUS !
	dv->tabValue = 0;
	readDir(dv);	// Aktuelles Item bergeben
	
	itemWithFocus = Liste;	
	
		
	pmMinus = new QPixmap((const char **)minus);
	pmPlus = new QPixmap((const char **)plus);
	pmLeer = new QPixmap((const char **)leer);
	pmFirstCorner = new QPixmap((const char **)firstcorner);
	pmSenk = new QPixmap((const char **)senk);
	pmWaage = new QPixmap((const char **)waage);
   connect(horSlider,SIGNAL(valueChanged(int)),this,SLOT(hchanged(int)));
   connect(verSlider,SIGNAL(valueChanged(int)),this,SLOT(vchanged(int)));

	// Verzeichnisbaum einlesen
	
}

dirviewItem *dirview::addItem(const char *text,const char *path)
{
	QString p(path);
	QString t(text);
	// Immer ein SLASH an den Path ran !
	if(p.right(1) != "/")
		p += "/";
	
	if(t != "/")
		if(t.right(1) == "/")
   		t = t.left(t.length()-1);
	
	dirviewItem *temp = new dirviewItem;
	temp->text = t;
	temp->path = p;
	temp->expandable = 2;	// voreinstellung: +
	temp->nextEntry = 0;

	if(!Liste)
	{
		Liste = temp;
		Liste->nextEntry = 0;
		Liste->prevEntry = 0;
	}
	else
	{
		dirviewItem *li = Liste;
		while(li->nextEntry)
			li = li->nextEntry;
		li->nextEntry = temp;
		temp->prevEntry = li;
	}
	if(temp->prevEntry != 0)
	{
		QString s1 = temp->prevEntry->path;
		QString s2 = temp->path;
		if(s2.left(s1.length())==s1)	// ist s1 Bestandteil von S2 ??
		{
			temp->tabValue = temp->prevEntry->tabValue +1;	// dann eins einrcken
		}
      else
			temp->tabValue = temp->prevEntry->tabValue ;		// ansonsten gleiche Spalte
		
	}
	else
	{
		temp->tabValue = 0;											// ansonsten 0 !
	}
	
	return temp;		
}

dirview::~dirview(){
	dirviewItem *li = Liste;
	dirviewItem *t;
	while(li)
	{
		t = li;
		li = li->nextEntry;
		delete t;
	}
	delete pmMinus;
	delete pmPlus;
	delete pmLeer;
	delete pmFirstCorner;
	delete pmSenk;
	delete pmWaage;
}


void dirview::resizeEvent(QResizeEvent *e)
{
	// Berechnen der Slider und der maximalen Items die sichtbar sind
	pmBuffer->resize(e->size().width()-4,e->size().height()-4);
	firstVisibleItem = Liste;	// spter ndern !!
	maxVisibleItems = (height()-4)/20;	// 20 Pixel ist ein Item hoch
	horSlider->setGeometry(0,height()-16,width(),16);
	verSlider->setGeometry(width()-16,0,16,height());
	rechne();
	refresh();
}

void dirview::readDir(dirviewItem *dv)
{
	
	if(dv->expandable == 0)	// wenn nicht expandierbar, dann zurck
		return;
	// wenn dieses Dir schon expanded ist, dann zurck
	if(dv->expandable == 1)
	{
		dv->expandable = 2;	// wieder verstecken
		return;
	}
	
	// hier ist expandable = 2

	// das Verzeichnis dv->path wird ausgelesen und unter diesem Item eingefgt
	dv->expandable = 1;
	dirviewItem *temp,								// ist immer das neueste Item
					*oldtemp = dv,						// oldtemp merkt sich den Vorgnger der Liste
					*restOfList = dv->nextEntry;	// der Rest der Liste
	temp = 0;
	QDir d(dv->path);		// Dir aus dv->path auslesen
	d.setFilter( QDir::Dirs | QDir::NoSymLinks | QDir::Hidden );
	d.setSorting( QDir::Name );

	const QFileInfoList *list = d.entryInfoList();
	QFileInfoListIterator it( *list );      // create list iterator
	QFileInfo *fi;                          // pointer for traversing
	
	int myCounter = 0;
	while ( (fi=it.current()) ) {           // for each file...
		if(fi->fileName() == "." || fi->fileName() == "..")
			;
		else
		{
			QString entry;
			entry = fi->fileName().data();
			temp = new dirviewItem;			// neues Item anlegen
			temp->nextEntry = 0;
			temp->prevEntry = oldtemp;		// Zeiger auf das Item davor
			temp->text = entry;
			temp->path = dv->path + entry + "/";
			temp->expandable = 2;
			temp->tabValue = dv->tabValue +1;
			oldtemp->nextEntry = temp;
			oldtemp = temp;
			myCounter++;
		}
		++it;                               // goto next list element
	}
   if(myCounter == 0)			// keine Unterdirectorys ??
   {
   	dv->expandable = 0;
//   	refresh();
   	return;
   }
	
	// jetzt RESTOFLIST wieder anhaengen
	temp->nextEntry = restOfList;
//	refresh();
}

void dirview::hchanged(int i)
{
}
void dirview::vchanged(int i)
{
	refresh();
}
void dirview::mouseDoubleClickEvent ( QMouseEvent *e )
{
	// Mauskoordinaten auswerten
//	int Spalte = e->x();
	int Zeile = e->y()/20;	// eine Zeile hat 20 Pixel
	
	// anhand der Zeile das passende Item heraussuchen
	dirviewItem *li = Liste;
	// y-coordinate der maus addieren
	for(int i=0;i<Zeile;i++)
	{
		li = li->nextEntry;
		if(!li) return;
	}
	// wenn slider nach unten verschoben wurde, diese differenz addieren
	for(int i=0;i<verSlider->value();i++)
	{
		li = li->nextEntry;
		if(!li) return;
	}
	// nun zeigt li auf das geklickte listitem

	
	// jetzt checken, ob maus auf dem Icon geklickt wurde
	QRect rect(li->tabValue*20+4,Zeile*20,20,20);
	// maus auf ICON ??
	if(!rect.contains(QPoint(e->x(),e->y())))
		goto noSymbolClicked;
	if(li->expandable == 2)	//ist es expandable ??
	{
		// Ja,
		// existiert berhaupt ein weiteres Item ?
		if(!li->nextEntry)
		{
			// nein, dann Verzeichnis lesen
			readDir(li);
		}
		else
		{
			// wenn tab des nchsten gleich ist mit jetzigem, dann
			// wurde Unterverzeichnis noch nicht eingelesen
			if(li->nextEntry->tabValue <= li->tabValue)
			{
				readDir(li);
			}
			else
			{
				// nur ausklappen
				li->expandable = 1;
			}
		}
		refresh();
		goto rechnen;
	}
	if(li->expandable == 0)
			goto rechnen;
	li->expandable = 2;
	refresh();
   goto rechnen;
	
noSymbolClicked:

	itemWithFocus = li;
	emit(dirSelected(li->path));
	refresh();


rechnen:
	rechne();
}


//*****************************************************************************************************
//*****************************************************************************************************
//*****************************************************************************************************
void dirview::paintEvent(QPaintEvent *e)
{
	refresh();
}
void dirview::refresh()
{

	QPainter paint(this);
	paint.setPen(QColor(0,0,0));
	paint.drawLine(0,0,width(),0);
	paint.drawLine(0,0,0,height());
	paint.setPen(QColor(150,150,150));
	paint.drawLine(0,1,width(),1);
	paint.drawLine(1,0,1,height());
	paint.setPen(QColor(200,200,200));
	paint.drawLine(1,height()-2,width()-2,height()-2);
	paint.drawLine(width()-2,height()-2,width()-2,1);

	QPainter buffer(pmBuffer);
	buffer.fillRect(0,0,width(),height(),lv->backgroundColor);
	
	dirviewItem *temp = Liste,*temp2;	

	for(int j = 0;j<verSlider->value();j++)
	{
		temp = temp->nextEntry;
	}
	
	bool flag = true;		// solange in schleife wie flag = true
	int tab;
	bool skip = false;
	int tabToSkip = 0;

	int 	i = maxVisibleItems,
			c=0;
	while(flag)
	{
		if(i==0) break;
   	QPixmap *tempPm=0;
      if(skip)
      {
      	if(temp->tabValue >= tabToSkip)
   	   {
      		goto skipEntry;
      	}
      	else
      		skip = false;
      }

      switch (temp->expandable)
      {
      	case 0:
      		tempPm = pmLeer;
      		break;
      	case 1:
      		tempPm = pmMinus;
      		break;
      	case 2:
      		tempPm = pmPlus;
      		break;
      }
		tab = temp->tabValue;
		
		// wenn focus, dann Blauen Hintergrund
		// die senkrechten Balken malen
		for(int j=1;j<tab;j++)
		{
			// hier muss noch kontrolliert werden, ob ein weiteres Hauptverzeichnis existiert
			if(checkDir(j,temp))
				bitBlt(pmBuffer,2+j*20,c*20,pmSenk);
		}
		
		if(tempPm == pmPlus)
		{
			// wenn nicht expandiert, dann alle weiteren eingerckten skippen
			skip = true;
			tabToSkip = tab +1;
			//und noch nen waagerechten balken
			bitBlt(pmBuffer,22+tab*20,c*20,pmWaage);
		}
		if(tempPm == pmLeer)
			bitBlt(pmBuffer,22+tab*20,c*20,pmWaage);

		bitBlt(pmBuffer,2+tab*20,c*20,tempPm);			// die kleine Pixmap in den Buffer blitten
		if(temp->expandable == 1)	// ist dieses expandiert ??
		{
			bitBlt(pmBuffer,22+tab*20,c*20,pmFirstCorner);
		}
		if(temp == itemWithFocus)
		{
			buffer.setPen(lv->cursorRand);
			buffer.setBrush(lv->backgroundColor);
			if(lv->cursorFilled)
			{
           	buffer.setBrush(lv->cursorColor);
	   	}
			buffer.drawRect(38+tab*20,c*20,width()-(tab*20)-56,20);
		}
		buffer.setPen(lv->forgroundColor);
		buffer.drawText(42+tab*20,(c+1)*20-7,temp->text);
		
		c++;
		if(--i == 0)
			flag = false;	// wenn max. Items dargestellt wurden, dann raus
skipEntry:
   				
		temp2 = temp;
		temp = temp->nextEntry;
		if(!temp)
			flag = false;	// wenn keine Items mehr folgen, dann raus
	}
		
	bitBlt(this,1,1,pmBuffer);
	
}
bool dirview::checkDir(int i,dirviewItem *di)
{
	if(!di->nextEntry)
		return false;
	
	bool flag = false;
	di = di->nextEntry;
	while(di)
	{
		if(di->tabValue == i)
			flag = true;
		if(di->tabValue < i)
			break;
		di = di->nextEntry;
	}
	return flag;
}


void dirview::rechne()
{
	int itemCount = 0;
	// alle SICHTBAREN items zhlen
	dirviewItem *dv = Liste;
	bool skip = false;
	skip = false;
	int tabToSkip = 0;
//	int tab = 0;
	while(dv)
	{
      if(skip)
      {
      	if(dv->tabValue >= tabToSkip)
   	   {
      		goto skipEntry2;
      	}
      	else
      		skip = false;
      }
		if(dv->expandable == 2)
		{
			// wenn nicht expandiert, dann alle weiteren eingerckten skippen
			skip = true;
			tabToSkip = dv->tabValue +1;
		}
		itemCount++;

skipEntry2:	
		dv = dv->nextEntry;
	}
	int max = itemCount - maxVisibleItems;	// z.B. 25 Items gibt es, davon werden max(20 z.b.) abgezogen
	if(max >0)
		verSlider->setRange(0,max);


}


void dirview::mousePressEvent ( QMouseEvent *e )
{
	// Mauskoordinaten auswerten
//	int Spalte = e->x();
	int Zeile = e->y()/20;	// eine Zeile hat 20 Pixel
	
	// anhand der Zeile das passende Item heraussuchen
	dirviewItem *li = Liste;
	// y-coordinate der maus addieren
	for(int i=0;i<Zeile;i++)
	{
		li = li->nextEntry;
		if(!li) return;
	}
	// wenn slider nach unten verschoben wurde, diese differenz addieren
	for(int i=0;i<verSlider->value();i++)
	{
		li = li->nextEntry;
		if(!li) return;
	}
	// nun zeigt li auf das geklickte listitem

	
	// jetzt checken, ob maus auf dem Icon geklickt wurde
	QRect rect(li->tabValue*20+4,Zeile*20,20,20);
	// maus auf ICON ??
	if(!rect.contains(QPoint(e->x(),e->y())))
		goto noSymbolClicked;
	if(li->expandable == 2)	//ist es expandable ??
	{
		// Ja,
		// existiert berhaupt ein weiteres Item ?
		if(!li->nextEntry)
		{
			// nein, dann Verzeichnis lesen
			readDir(li);
		}
		else
		{
			// wenn tab des nchsten gleich ist mit jetzigem, dann
			// wurde Unterverzeichnis noch nicht eingelesen
			if(li->nextEntry->tabValue <= li->tabValue)
			{
				readDir(li);
			}
			else
			{
				// nur ausklappen
				li->expandable = 1;
			}
		}
		refresh();
		goto rechnen;
	}
	if(li->expandable == 0)
			goto rechnen;
	li->expandable = 2;
	refresh();
   goto rechnen;
	
noSymbolClicked:

/*
	itemWithFocus = li;
	emit(dirSelected(li->path));
	refresh();
*/

rechnen:
	rechne();
}
