/****************************************************************************
	This file is a part of the KCommander
	(c) 2000, GPL'ed

	(Written by cp <de_cp@yahoo.com>)

******************************************************************************/


#include "dlgfformat.h"
#include <kapp.h>
#include <stdlib.h>

/*******************************************************************************
	class dlgFFormat
********************************************************************************/

dlgFFormat::dlgFFormat( QWidget *parent, const char *name )
	: QDialog( parent, name, true )
{
	ok = new QPushButton( kl.translate("OK"), this );
	ok->setDefault(true);
	ok->setFocus();

	cancel = new QPushButton( kl.translate("Cancel"), this );

	fdev = new QComboBox( false, this );
	fdev->insertItem( kl.translate("/dev/fd0") );
	fdev->insertItem( kl.translate("/dev/fd1") );

	devHelp = new QLabel( this );
	devHelp->setText( "Please select the floppy device of your\nchoice here." );
	devHelp->setAlignment(AlignTop);

	fsselect = new QComboBox( false, this );
	fsselect->insertItem( kl.translate("Second extended FS") );
	fsselect->insertItem( kl.translate("DOS (FAT)") );

	fsHelp = new QLabel( this );
	fsHelp->setText( QString ("Please chose the file system.\n")
		+("The second extended file system is the default\n")
		+("Linux FS, while FAT is compatible with (MS-)DOS.") );
	fsHelp->setAlignment(AlignTop);

	lowLevel = new QCheckBox( kl.translate("Low level format (slow)"), this );

	setCaption( kl.translate("Format floppy") );
	setMinimumSize( 400, 250 );
	setMaximumSize( 550, 350 );
	resize( 450, 250 );

	connect( ok, SIGNAL(clicked()), SLOT(accept()) );
	connect( cancel, SIGNAL(clicked()), SLOT(reject()) );
}

void dlgFFormat::resizeEvent( QResizeEvent *evt )
{
	ok->setGeometry( width()/3-45, height()-40, 90, 30 );
	cancel->setGeometry( 2*width()/3-45, height()-40, 90, 30 );

	fdev->setGeometry( 20, 20, width()/3, 30 );
	devHelp->setGeometry( 30+width()/3, 20, width()-width()/3-40, 50 );
	fsselect->setGeometry( 20, 70, width()/3, 30 );
	fsHelp->setGeometry( 30+width()/3, 70, width()-width()/3-40, 50 );

	lowLevel->setGeometry( 20, 120, width()-40, 25 );
}


/*******************************************************************************
	class formatMan
********************************************************************************/

formatMan::formatMan() : QObject( 0L )
{
	prStep = 0; fFS = 0;
   process = 0;            // 0 nothing have done
                           // 1 formatting ready
   last = 0;
   visual = 0L;
	
	lowLevel = new KProcess();
	mkext2 = new KProcess();
	mkmsdos = new KProcess();

	connect( lowLevel, SIGNAL( processExited(KProcess*) ),
		SLOT( prExit( KProcess * ) ) );
	connect( lowLevel, SIGNAL( receivedStdout (KProcess *, char *, int ) ),
		SLOT( formatOutput (KProcess *, char *, int) ) );


	connect( mkext2, SIGNAL( processExited(KProcess*) ),
		SLOT( prExit( KProcess * ) ) );
	connect( mkext2, SIGNAL( receivedStdout (KProcess *, char *, int ) ),
		SLOT( formatOutput (KProcess *, char *, int) ) );

	connect( mkmsdos, SIGNAL( processExited(KProcess*) ),
		SLOT( prExit( KProcess * ) ) );
	connect( mkmsdos, SIGNAL( receivedStdout (KProcess *, char *, int ) ),
		SLOT( formatOutput (KProcess *, char *, int) ) );
}

formatMan::~formatMan()
{
   delete visual;
	//Kill processes (...)
}

void formatMan::invoke()
{
	dlgInv = new dlgFFormat();
	visual = new QWidget();
	int x=0; int y=0;
	for(int i = 0;i<80;i++)
	{
	   debug("neue Lampe");
//	   lamps[i] = new KLed ( KLed::red, KLed::On, KLed::round,visual);
      lamps[i] = (KLed *)new QWidget(visual);
      lamps[i]->show();
      lamps[i]->setGeometry(10 + x*20,10 + y*20,15,15);
      lamps[i]->setBackgroundColor(QColor(0xa0b0c0));
   	kapp->processEvents();
	   x++;
	   if(x==10)
	   {
	      x=0;y++;
	   }
	}
	dlgInv->show();

	if( dlgInv->result() == QDialog::Accepted )
		invoke( dlgInv->selDev(), dlgInv->selFS(), dlgInv->isLow() );

}

void formatMan::invoke( int devId, int fsId, bool isLL )
{
QString devStr;

	switch( devId )
	{
		case 0: devStr = "/dev/fd0";
			break;

		case 1: devStr = "/dev/fd1";
			break;

		default:
			fatal( "in formatMan::invoke(int,int,bool): fatal error" );
	}

	lowLevel->clearArguments();
	lowLevel->setExecutable( "fdformat" );
	*lowLevel << (const char *)devStr;

	mkext2->clearArguments();
	mkext2->setExecutable( "mkfs.ext2" );
	*mkext2 << (const char *)devStr;

	mkmsdos->clearArguments();
	mkmsdos->setExecutable( "mkfs.msdos" );
	*mkmsdos << (const char *)devStr;

	if(isLL)
		prStep = 0;
	else
		prStep = 1;

	fFS = fsId;

	debug( "Formatting %s", (const char *)devStr );

	doNext();
}


void formatMan::doNext()
{
	visual->show();
	switch( prStep )
	{
		case 0: //low level format
			prStep = 1;
			lowLevel->start(KProcess::Block,KProcess::All);
			break;

		case 1: //mkfs
			prStep = 2;

			if( fFS == 0 )
				mkext2->start(KProcess::Block,KProcess::All);
			else
				mkmsdos->start(KProcess::Block,KProcess::All);
			break;

		case 2: //OK-message
			prStep = 3;

			KMsgBox::message( 0L, "Floppy formatted",
				"Floppy formatted" );
			break;

		default: //ignore
			break;
	}
}

void formatMan::prExit( KProcess *kp ) //SLOT
{
	if( kp->normalExit() && kp->exitStatus() == 0 )
		doNext();
	else
		KMsgBox::message( 0L, "KCommander - formatting error",
			"Some error occured while formatting the floppy." );
}
void formatMan::formatOutput (KProcess *proc, char *buffer, int buflen)
{
   visual->resize(300,300);
   QString s = buffer;
   QString command;
   int a;
   switch( prStep )
   {
      case 1:  // low level format
      {
      	int x=0; int y=0;
         s = s.left(3);
         a = atoi(s);
         if(a < last)
            process++;
         switch(process)
         {
            case 0:  command = "Formatting"; break;
            case 1:  command = "Verifying";  break;
            default: command = "";           break;
         }
         if(command != "")
         {
            if(process == 0)
            {
               lamps[a]->setBackgroundColor(red);
            }
            if(process == 1)
            {
               lamps[a]->setBackgroundColor(green);
            }
            // var COMMAND als Label ins Window setzen
            visual->setCaption(command);
            kapp->processEvents(10);
            last = a;
         }
         break;
      }
      case 2:
         break;
      default:
         break;
   }
}
